require('./node_modules/dotenv').config()
const webpack = require('webpack');

const path = require('path');
const dotenv = require('dotenv');
/*const { spawn } = require('child_process');*/

//LOAD THE RIGHT FILE
dotenv.config({
  path: path.resolve(__dirname,  '.env.'+process.env.NODE_ENV)
});

var modules = [
  // Doc: https://bootstrap-vue.js.org
  'bootstrap-vue/nuxt',

  // Axios
  '@nuxtjs/axios',

  // Pwa
  /*'@nuxtjs/pwa',

  'nuxt-basic-auth-module',*/

  ['nuxt-lazy-load', {
    // These are the default values
    images: true,
    videos: true,
    audios: true,
    iframes: true,
    native: false,
    polyfill: true,
    directiveOnly: false,
    
    // Default image must be in the static folder 
    defaultImage: '/default.jpg',

    // To remove class set value to false
    loadingClass: 'isLoading',
    loadedClass: 'isLoaded',
    appendClass: 'lazyLoad',
    
    observerConfig: {
      // See IntersectionObserver documentation
    }
  }],

  [
    'nuxt-compress',
    {
      gzip: {
        threshold: 8192,
      },
      brotli: {
        threshold: 8192,
      },
    },
  ]
  
]

module.exports = {
  /*basic: {
    name: 'toulouseweb',
    pass: 'Kj*LZUL-@48pE9KL',
    message: 'Entrez votre login et mot de passe',
    enabled: true,
    match({ url }) {
      return (url || '').startsWith('/admin') 
    },
  },*/
  env: {
    API_URL: process.env.API_URL,
    imgURL: process.env.imgURL,
    clientUrl: process.env.clientUrl,
    clientHost: process.env.clientHost,
    clientSite: process.env.clientSite,
  },
  router: {
    extendRoutes(routes, resolve) {
      routes.push({
        name: 'annuaireCat',
        path: '/annuaire/:cat?/:scat1?/:scat2?',
        component: resolve(__dirname, 'pages/annuaire.vue')
      })
      routes.push({
        name: 'articleFiche',
        path: '/fiche/:p1?/:p2?/:p3?/:p4?/:p5?/:p6?',
        component: resolve(__dirname, 'pages/article.vue')
      })
      routes.push({
        name: 'bonsPlans',
        path: '/bons-plans/:cat?',
        component: resolve(__dirname, 'pages/bons_plans.vue')
      })
      routes.push({
        name: 'annuaireEnfant',
        path: '/enfants',
        component: resolve(__dirname, 'pages/annuaire.vue')
      })
      routes.push({
        name: 'annuaireSport',
        path: '/sports',
        component: resolve(__dirname, 'pages/annuaire.vue')
      })
      routes.push({
        name: 'annuaireBoutique',
        path: '/boutique',
        component: resolve(__dirname, 'pages/annuaire.vue')
      })
      routes.push({
        name: 'annuaireMariage',
        path: '/mariage',
        component: resolve(__dirname, 'pages/annuaire.vue')
      })
      routes.push({
        name: 'annuaireRestau',
        path: '/restaurants',
        component: resolve(__dirname, 'pages/annuaire.vue')
      })
      routes.push({
        name: 'annuaireSpectacle',
        path: '/spectacles',
        component: resolve(__dirname, 'pages/annuaire.vue')
      })
      routes.push({
        name: 'annuaireLanuit',
        path: '/la-nuit',
        component: resolve(__dirname, 'pages/annuaire.vue')
      })
      routes.push({
        name: 'newsDetail',
        path: '/news/:slug',
        component: resolve(__dirname, 'pages/news.vue')
      })
      routes.push({
        name: 'filmDetail',
        path: '/film/:slug',
        component: resolve(__dirname, 'pages/film.vue')
      })
      routes.push({
        name: 'film-commentaire-det',
        path: '/film-commentaire/:slug',
        component: resolve(__dirname, 'pages/film-commentaire.vue')
      })
      routes.push({
        name: 'film-salle-det',
        path: '/film-salle/:slug',
        component: resolve(__dirname, 'pages/film-salle.vue')
      })
      routes.push({
        name: 'film-avis-det',
        path: '/film-avis/:slug',
        component: resolve(__dirname, 'pages/film-avis.vue')
      })
      routes.push({
        name: 'salleList',
        path: '/cinema/salle/:slug',
        component: resolve(__dirname, 'pages/salle.vue')
      })
      routes.push({
        name: 'cinema',
        path: '/cinema',
        component: resolve(__dirname, 'pages/cinema.vue')
      })
      routes.push({
        name: 'panorama',
        path: '/film-panorama',
        component: resolve(__dirname, 'pages/film-panorama.vue')
      })
      routes.push({
        name: 'filmsalle',
        path: '/film-salle/:slug',
        component: resolve(__dirname, 'pages/film-salle.vue')
      })
      routes.push({
        name: 'agenda-list',
        path: '/agenda/:slug',
        component: resolve(__dirname, 'pages/agenda.vue')
      })
      routes.push({
        name: 'agendaDetail',
        path: '/agenda-fiche/:id',
        component: resolve(__dirname, 'pages/agenda-detail.vue')
      })
      routes.push({
        name: 'annonces-new-det',
        path: '/annonces/:p1?/:p2?/:p3?/:p4?/:p5?/:p6?',
        component: resolve(__dirname, 'pages/annonces.vue')
      })
      /*routes.push({
        name: 'adm-stat',
        path: '/admin',
        component: resolve(__dirname, 'pages/admin/stat.vue')
      })
      routes.push({
        name: 'adm-agenda',
        path: '/admin/agenda',
        component: resolve(__dirname, 'pages/admin/agenda.vue')
      })
      routes.push({
        name: 'adm-annonce',
        path: '/admin/annonces',
        component: resolve(__dirname, 'pages/admin/annonces.vue')
      })
      routes.push({
        name: 'adm-article',
        path: '/admin/article',
        component: resolve(__dirname, 'pages/admin/article.vue')
      })
      routes.push({
        name: 'adm-article-suppr',
        path: '/admin/article-supprimer',
        component: resolve(__dirname, 'pages/admin/article-supprimer.vue')
      })
      routes.push({
        name: 'adm-cat-encart',
        path: '/admin/categories-encart',
        component: resolve(__dirname, 'pages/admin/categories-encart.vue')
      })
      routes.push({
        name: 'adm-cinema',
        path: '/admin/cinema',
        component: resolve(__dirname, 'pages/admin/cinema.vue')
      })
      routes.push({
        name: 'adm-contact',
        path: '/admin/contact',
        component: resolve(__dirname, 'pages/admin/contact.vue')
      })
      routes.push({
        name: 'adm-forum',
        path: '/admin/forum',
        component: resolve(__dirname, 'pages/admin/forum.vue')
      })
      routes.push({
        name: 'adm-news',
        path: '/admin/news',
        component: resolve(__dirname, 'pages/admin/news.vue')
      })
      routes.push({
        name: 'adm-rencontre',
        path: '/admin/rencontre',
        component: resolve(__dirname, 'pages/admin/rencontre.vue')
      })
      routes.push({
        name: 'adm-seo',
        path: '/admin/seo',
        component: resolve(__dirname, 'pages/admin/seo.vue')
      })
      routes.push({
        name: 'adm-sites-contact',
        path: '/admin/sites-contact',
        component: resolve(__dirname, 'pages/admin/sites-contact.vue')
      })
      routes.push({
        name: 'adm-slider',
        path: '/admin/slider',
        component: resolve(__dirname, 'pages/admin/slider.vue')
      })
      routes.push({
        name: 'adm-login',
        path: '/admin',
        component: resolve(__dirname, 'pages/admin/index.vue')
      })*/
      routes.push({
        name: 'cineMaps',
        path: '/cine-maps/:slug?',
        component: resolve(__dirname, 'pages/cine-maps.vue')
      })
      routes.push({
        name: 'restoMaps',
        path: '/resto-maps/:slug?',
        component: resolve(__dirname, 'pages/resto-maps.vue')
      })
    }

  },
  /*
  ** Nuxt generate dynamic routes
  */
  // generate: {
  //   routes: [
  //     'about',
  //     'portfolio',
  //   ]
  // },
  
  /*  
  ** Nuxt rendering mode
  ** See https://nuxtjs.org/api/configuration-mode
  */
  //deprecated
  //mode: 'spa',//'universal',//'client',//'spa',
  ssr: 'universal',
  /*
  ** Nuxt target
  ** See https://nuxtjs.org/api/configuration-target
  */
  target: 'server',

  serverMiddleware: [
    { path: '/', handler: './server/redirects'}
  ],

  /**
   * Nuxt telemetry
   * 
   */
  /*telemetry: false,*/

  async: true,

  render: {
    // Setting up cache for 'static' directory - a year in milliseconds
    // https://web.dev/uses-long-cache-ttl
    static: {
      maxAge: 60 * 60 * 24 * 365 * 1000,
    },
    resourceHints: false,
    preload: true,
    prefetch: false,
    async: true,
  },
  /*
  ** Headers of the page
  ** See https://nuxtjs.org/api/configuration-head
  */
  head: { 
    title: 'Toulouse Web, le 1er portail guide annuaire web toulousain',
    htmlAttrs: {
      lang: 'fr'
    },
    meta: [
      { charset: 'utf-8' },
      { name: 'viewport', content: 'width=device-width, initial-scale=1' },
    ],
    link: [
      { rel: 'icon', type: 'image/x-icon', href: '/favicon.ico' },
    ],
    link: [
      { rel: 'apple-touch-icon', sizes: '120x30', href: '/apple-touch-icon-120x30-precomposed.png' },
    ],
    link: [
      { rel: 'apple-touch-icon', sizes: '152x38', href: '/apple-touch-icon-152x38-precomposed.png' },
    ],
    __dangerouslyDisableSanitizers: ['script'],
    script: [
        {
            hid: 'gtm-script1',
            async: true,
            rel: 'preconnect',
            src: 'https://www.google-analytics.com/analytics.js',
            body: true
        },
        {
            hid: 'gtm-script2',
            async: true,
            rel: 'preconnect',
            src: 'https://www.googletagmanager.com/gtag/js?id=G-N2PLZW2FJL&l=dataLayer&cx=c',
            body: true
        }, 
        {
            hid: 'gtm-script3',
            async: true,
            rel: 'preconnect',
            src: 'https://www.googletagmanager.com/gtag/js?id=UA-205074203-1',
            body: true
        }, 
        {
          hid: 'gtm-script4',
          innerHTML: `
            window.dataLayer = window.dataLayer || [];
            function gtag(){dataLayer.push(arguments);}
            gtag('js', new Date());
          
            gtag('config', 'UA-205074203-1');
          `,
          type: 'text/javascript',
          charset: 'utf-8',
          defer: true,
          async: true,
          rel: 'preconnect',
          body: true
        },
        {
          hid: 'gtm-script5',
          innerHTML: `
            window.dataLayer = window.dataLayer || [];
            function gtag(){dataLayer.push(arguments);}
            gtag('js', new Date());
          
            gtag('config', 'G-N2PLZW2FJL');
          `,
          type: 'text/javascript',
          charset: 'utf-8',
          defer: true,
          async: true,
          rel: 'preconnect',
          body: true
        },
        {
          hid: 'organization-structured-data',
          type: 'application/ld+json',
          innerHTML: `{
            "@context": "http://schema.org",
            "@id": "https://toulouseweb.com/#organization",
            "@type": "Organization",
            "name": "Toulouseweb",
            "url": "https://toulouseweb.com/",
            "logo": "https://toulouseweb.com/_nuxt/img/logo.c085ee1.png",
            "description": "Toulouseweb est un portail city-guide de Toulouse pour trouver toutes les bonnes adresses de la ville rose, pour sortir, se loger, faire du shopping et bien plus. On peut aussi y passer des petites annonces gratuites et retrouver toutes sortes d'actualités toulousaines, des infos sur Toulouse mais aussi sur la région toulousaine.",
            "contactPoint":          
                          {
                          "@type": "ContactPoint",
                          "phone": " +33534605958",
                          "contactType": "customer support",
                          "areaServed":"FR"
                          },
            "sameAs": [
                "https://www.instagram.com/toulouseweb/",          
                "https://www.facebook.com/toulouseweb"
            ]
          }`,
          body: true
        }
    ]
  },
  /*
  ** Global CSS
  */
  css: [
  ],
  /*
  ** Plugins to load before mounting the App
  ** https://nuxtjs.org/guide/plugins
  */
  plugins: [
    '~plugins/vue-notification',
    '~plugins/vue-perfect-scrollbar',
    { src: '~plugins/v-calendar.js', ssr: false },
    /*{ src: '~/plugins/vue2-editor', ssr: false}*/
    /*{ src: '~/plugins/analytics.js', async: true, body: true }*/
  ],
  /*
  ** Auto import components
  ** See https://nuxtjs.org/api/configuration-components
  */
  components: false,
  /*
  ** Nuxt.js dev-modules
  */
  buildModules: [
    // import globale style
    /*'@nuxtjs/style-resources',*/
    // Define global components
    /*'@nuxtjs/global-components',*/
    /*['@nuxtjs/vuetify', {
    }],*/

    /*['@nuxtjs/google-analytics', 
      id: 'G-N2PLZW2FJL',
      debug: { sendHitTask: true }
    ]*/
    ['nuxt-compress']
  ],
  /**
   * Global styles
   */
  styleResources: {
    scss: [
      './assets/css/sass/themes/multiply.light.scss',
      './assets/css/sass/_mixins.scss',
    ]
  },
  /**
   * Globale components options
   */
  globalComponents: {
    // options
  },
  /*
  ** Nuxt.js modules
  */
  modules: modules,

  bootstrapVue: {

    icons: false,
  },

  /*sitemap: {
    hostname: 'https://toulouseweb.com',
    gzip: true,
    exclude: [ '/admin/**'],
    routes: ['/agenda?genre=salons', '/agenda?genre=theatre', '/agenda?genre=bien-etre']
  },*/

  /*cache: {
    useHostPrefix: false,
    pages: [

      '/'
    ],
    
    key(route, context) {

    },
 
    store: {
      type: 'memory',
      max: 10000,
      ttl: 36000000,
    },
  },*/
  /*mq: {
    defaultBreakpoint: "desktop",
    breakpoints: {
      mobile: 768,
      tablet: 1024,
      desktop: 1400,
      desktopWide: 2000,
      desktopUltraWide: Infinity
    }
  },*/
  /*
  ** Build configuration
  ** See https://nuxtjs.org/api/configuration-build/
  */
  build: {
    cssSourceMap: true,
    extractCSS: true,
    /*optimization: {
      minimize: true,
      splitChunks: {
        chunks: 'async',
        maxSize: 300000
      }
    },*/
    splitChunks: {
      pages: true,
      vendor: false,
      commons: false,
      runtime: false,
      layouts: true
    },
  }
}